from pathlib import Path

TEMPLATES_DIR = Path(__file__).parent / "templates"

TEMPLATES = {
    "etl": {
        "description": "Extract-Transform-Load pipeline",
        "dir": "template",
        "etl_types": ["standard", "medallion"],
    },
    "ml": {
        "description": "Machine learning pipeline",
        "dir": "template",
        "ml_types": ["training","inference","full_pipeline","feature_engineering"],
    },
    "utility": {
        "description": "Utility / helper library",
        "dir": "utility",
        "etl_types": [],
    },
}
